@@ -11,7 +11,7 @@ use List::Util qw(reduce);
 use PYX::Parser;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -247,6 +247,39 @@ PYX::Hist - Processing PYX data or file and print histogram.
  # Parse.
  $obj->parse($pyx);
 
+ # Output:
+ # PYX::Hist: Bad end of element.
+ # Element: middle
+
+=head1 EXAMPLE3
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Error::Pure;
+ use PYX::Hist;
+
+ # Error output.
+ $Error::Pure::TYPE = 'PrintVar';
+
+ # Example data.
+ my $pyx = <<'END';
+ (begin
+ (middle
+ (end
+ -data
+ )end
+ )middle
+ END
+
+ # PYX::Hist object.
+ my $obj = PYX::Hist->new;
+
+ # Parse.
+ $obj->parse($pyx);
+
  # Output:
  # PYX::Hist: Stack has some elements.
 
@@ -279,11 +312,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2015 Michal Špaček
+ © 2014-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
